upoints

Package upoints |
[hide private]
[frames] | no frames]

# Package upoints

upoints - Modules for working with points on Earth.

`upoints` is a collection of GPL v3 licensed modules for working with points on Earth, or other near spherical objects. It allows you to calculate the distance and bearings between points, mangle xearth/xplanet data files, work with online UK trigpoint databases, NOAA's weather station database and other such location databases.

The upoints.point module is the simplest interface available, and is mainly useful as a naïve object for simple calculation and subclassing for specific usage. An example of how to use it follows:

    >>> Home = point.Point(52.015, -0.221)
    >>> Telford = point.Point(52.6333, -2.5000)
    >>> int(Home.distance(Telford))
    169
    >>> int(Home.bearing(Telford))
    294
    >>> int(Home.final_bearing(Telford))
    293
    >>> import datetime
    >>> Home.sun_events(datetime.date(2007, 6, 28))
    (datetime.time(3, 42), datetime.time(20, 25))
    >>> Home.sunrise(datetime.date(2007, 6, 28))
    datetime.time(3, 42)
    >>> Home.sunset(datetime.date(2007, 6, 28))
    datetime.time(20, 25)

Version: 0.11.0

Author: James Rowe

Copyright: Copyright (C) 2007-2008 James Rowe

Status: WIP

License: GNU General Public License Version 3

Date: 2008-05-20

Submodules | [hide private]
upoints.baken: baken - Imports baken data files upoints.cellid: cellid - Imports OpenCellID data files upoints.cities: cities - Imports GNU miscfiles cities data files upoints.geonames: geonames - Imports geonames.org data files upoints.gpx: gpx - Imports GPS eXchange format data files upoints.kml: kml - Imports KML data files upoints.nmea: nmea - Imports GPS NMEA-formatted data files upoints.osm: osm - Imports OpenStreetMap data files upoints.point: point - Class for working with locations on Earth upoints.trigpoints: trigpoints - Imports trigpoint marker files upoints.tzdata: tzdata - Imports timezone data files from UNIX zoneinfo upoints.utils: utils - Support code for upoints upoints.weather_stations: weather_stations - Imports weather station data files upoints.xearth: xearth - Imports xearth-style marker files

Variables | [hide private]
| __version__ = ``'``0.11.0``'``
| __author__ = ``'``James Rowe <jnrowe@ukfsn.org>``'``
| __copyright__ = ``'``Copyright (C) 2007-2008 James Rowe``'``
| __license__ = ``'``GNU General Public License Version 3``'``
| __credits__ = ``'``C\xc3\xa9dric Dufour, Kelly Turner, Simon Woods``'``
| __history__ = ``'``See Mercurial repository``'``